@@ -1,5 +1,5 @@
 #
-# $Id: xpTheme.tcl,v 1.26 2005/03/15 16:47:29 jenglish Exp $
+# $Id: xpTheme.tcl,v 1.27 2005/09/14 17:24:28 jenglish Exp $
 #
 # Tile widget set: XP Native theme
 #
@@ -12,9 +12,10 @@ namespace eval tile {
 	# NOTE: MS documentation says to use "Tahoma 8" in Windows 2000 / XP,
 	# although many MS programs still use "MS Sans Serif 8"
 	#
-	style default . -font "Tahoma 8"
+	#style configure . -font "Tahoma 8"
+	style configure . -font TkDefaultFont
 
-	style default . \
+	style configure . \
 	    -background SystemButtonFace \
 	    -foreground SystemWindowText \
 	    -selectforeground SystemHighlightText \
@@ -25,21 +26,21 @@ namespace eval tile {
 	    -foreground [list disabled SystemGrayText] \
 	    ;
 
-	style default TButton -padding {1 1} -width -11
-	style default TMenubutton -padding {8 4}
+	style configure TButton -padding {1 1} -width -11
+	style configure TMenubutton -padding {8 4}
 
-	style default TNotebook -expandtab {2 2 2 2}
+	style configure TNotebook -expandtab {2 2 2 2}
 
-	style default TLabelframe -foreground "#0046d5"
+	style configure TLabelframe -foreground "#0046d5"
 
 	# OR: -padding {3 3 3 6}, which some apps seem to use.
-	style default TEntry -padding {2 2 2 4}
+	style configure TEntry -padding {2 2 2 4}
 	style map TEntry \
 	    -selectbackground [list !focus "#c3c3c3"] \
 	    -selectforeground [list !focus "#000000"] \
 	    ;
-	style default TCombobox -padding 2
+	style configure TCombobox -padding 2
 
-	style default Toolbutton -padding {4 4}
+	style configure Toolbutton -padding {4 4}
     }
 }
